#schmecko

```
pip install schmecko
schmecko -h
usage: schmecko [-h] [-p PORT] [--host HOST]

optional arguments:
  -h, --help            show this help message and exit
  -p PORT, --port PORT
  --host HOST
```
